@@ -1,5 +1,5 @@
 from argparse import ArgumentParser
-from convert import GeneratePPT
+from cast_arg.convert import GeneratePPT
 from cast_arg.config import Config
 
 __author__ = "Nevin Kaplan"
