@@ -100,7 +100,12 @@ class AipData(AipRestCall):
                     self._data[s]['critical_rules']=self.get_rules(domain_id,self._data[s]['snapshot']['id'],60017,non_critical=False)
 
                     self.info('ISO rules')
-                    self._data[s]['ISO']=self.__get_iso_rules(domain_id,snapshot['id'])
+                    self._data[s]['ISO']=self._get_iso_rules(domain_id,snapshot['id'])
+
+                    # self.info('Green IT Index')
+                    # self._data[s]['GreenIT']=self._get_green_rules(domain_id,snapshot['id'])
+
+
 
                     self.info('action plan data')
                     (ap_df,ap_summary_df) = self.get_action_plan(domain_id,self._data[s]['snapshot']['id']) 
@@ -119,7 +124,35 @@ class AipData(AipRestCall):
     def iso_rules(self, app):
         return self._data[app]['ISO']
 
-    def __get_iso_rules(self,domain_id,snapshot_id):
+    def _get_green_it_rules(self,domain_id,snapshot_id):
+        iso={20140522:"Green IT Index"}
+
+        rslt_df = DataFrame()
+        rslt_df.style.set_properties(subset=['text'],**{'text-align': 'left'})
+        for key, value in iso.items():
+            try:
+                temp = DataFrame(columns=['category','violation'])
+                rp = json_normalize(self.get_rules(domain_id,snapshot_id,key)['rulePattern'])
+                temp['violation'] = rp['name']
+                temp['category'] = value
+                temp = temp.groupby(['category','violation']).size().reset_index(name='count') 
+
+                total = temp.groupby(['category'])['count'].sum().reset_index(name='count') 
+                total['violation']=''
+                total = total[['category','violation','count']]
+
+                rslt_df = concat([rslt_df,total,temp])
+            except KeyError as e:
+                self.warning(f'no iso rules for {value} ({e})')
+
+        if 'category' in rslt_df.columns:
+            rslt_df['category'] = rslt_df['category'].mask(rslt_df['category'].ne(rslt_df['category'].shift()).cumsum().duplicated(), '')
+        else:
+            self.warning('No ISO rules found')
+            
+        return rslt_df
+
+    def _get_iso_rules(self,domain_id,snapshot_id):
         iso={1061004:"Security",
              1061003:"Reliabllity",
              1061002:"Performance-Efficiency",
